### R code from vignette source 'vegdata.Rnw'
### Encoding: ISO8859-1

###################################################
### code chunk number 1: prep
###################################################
options(width=100,digits=2)


###################################################
### code chunk number 2: vegdata.Rnw:42-43 (eval = FALSE)
###################################################
## vignette('vegdata')


###################################################
### code chunk number 3: load
###################################################
library(vegdata)


###################################################
### code chunk number 4: vegdata.Rnw:90-91
###################################################
tv.home()


###################################################
### code chunk number 5: vegdata.Rnw:95-96 (eval = FALSE)
###################################################
## options(tv_home="path_to_your_Turboveg_root_directory")


###################################################
### code chunk number 6: vegdata.Rnw:99-100
###################################################
options(tv_home=system.file('tvdata', package='vegdata'))


###################################################
### code chunk number 7: dblisting
###################################################
tv.db()


###################################################
### code chunk number 8: vegdata.Rnw:110-111
###################################################
tv.refl()


###################################################
### code chunk number 9: tax
###################################################
tax('Achillea millefolium')


###################################################
### code chunk number 10: vegdata.Rnw:123-124
###################################################
tax('Achillea millefolium', strict=TRUE, verbose=TRUE) 


###################################################
### code chunk number 11: syn
###################################################
tax('Elytrigia repens')$TaxonName
syn('Elytrigia repens')


###################################################
### code chunk number 12: childs
###################################################
childs(27, quiet=TRUE)$TaxonName
parents('ACHIMIL')


###################################################
### code chunk number 13: db
###################################################
db <- 'taxatest'


###################################################
### code chunk number 14: meta (eval = FALSE)
###################################################
## tv.metainfo(db)


###################################################
### code chunk number 15: obs
###################################################
obs.tax <- tv.obs(db)
# Adding species names
species <- tax('all')
obs.tax$TaxonName <-  species$TaxonName[match(obs.tax$TaxonUsageID, species$TaxonUsageID)]
head(obs.tax[,c('RELEVE_NR','TaxonUsageID','COVER_CODE','LAYER','TaxonName')])


###################################################
### code chunk number 16: taxval
###################################################
obs.taxval <- taxval(obs.tax, db=db, mono='lower')


###################################################
### code chunk number 17: Taxon
###################################################
obs.taxval$TaxonName <-  species$TaxonName[match(obs.taxval$TaxonUsageID, species$TaxonUsageID)]
obs.taxval[,c('RELEVE_NR', 'COVER_CODE', 'TaxonName')]


###################################################
### code chunk number 18: coarsen
###################################################
tmp <- taxval(obs.tax, refl='GermanSL 1.2', ag='adapt', rank='FAM')
tmp$oldTaxon <- tax(obs.tax$TaxonUsageID, refl='GermanSL 1.2')$TaxonName
tmp$newTaxon <- tax(tmp$TaxonUsageID, refl='GermanSL 1.2')$TaxonName


###################################################
### code chunk number 19: print.coarsen
###################################################
head(tmp[,c('oldTaxon','newTaxon')], 10)


###################################################
### code chunk number 20: taxonviews (eval = FALSE)
###################################################
## newconcept <- taxval(obs, db=db, concept='korneck1996')


###################################################
### code chunk number 21: coverperc
###################################################
obs <- tv.obs(db)
obs <- tv.coverperc(db, obs)
head(obs)


###################################################
### code chunk number 22: pseudo1 (eval = FALSE)
###################################################
## data(lc.0)
## tv.veg(db, pseudo = list(lc.0, c("LAYER")), lc = "layer")


###################################################
### code chunk number 23: lc0
###################################################
data(lc.0)
tmp <- tv.veg(db, tax=FALSE, pseudo = list(lc.0, "LAYER"), lc = "layer", quiet=TRUE)
names(tmp)


###################################################
### code chunk number 24: Season
###################################################
comb <- list(data.frame(SEASON=0:4, COMB=c(0,'Spring','Summer','Autumn','Winter')),'SEASON')
names(tv.veg(db, tax=FALSE, pseudo=comb, quiet=TRUE))


###################################################
### code chunk number 25: layer
###################################################
data(lc.1)
veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, quiet=TRUE)


###################################################
### code chunk number 26: layerdiff
###################################################
veg[,1:10]


###################################################
### code chunk number 27: vegdata.Rnw:348-349
###################################################
obs.tax$TaxonUsageID[obs.tax$TaxonUsageID == 27] <- 31


###################################################
### code chunk number 28: replace
###################################################
taxon.repl <- data.frame(old=c(27), new=c(31))
obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID, match(taxon.repl$old, obs.tax$TaxonUsageID), taxon.repl$new)


###################################################
### code chunk number 29: comb.spec
###################################################
veg <- tv.veg('taxatest', quiet=TRUE)
comb.species(veg, sel=c('QUERROB','QUERROB.Tree'))


###################################################
### code chunk number 30: site.echo
###################################################
site <- tv.site(db)


###################################################
### code chunk number 31: VegetWeb (eval = FALSE)
###################################################
## source('http://geobot.botanik.uni-greifswald.de/download/r_package/vegetweb.r')


###################################################
### code chunk number 32: ESVeg
###################################################
download.file('http://geobot.botanik.uni-greifswald.de/download/data/T302.xml', "T302.xml")
T302.site <- ESveg.site('T302.xml')
T302.site <- T302.site[!is.na(T302.site$LONGITUDE),]


###################################################
### code chunk number 33: vegdata.Rnw:406-407 (eval = FALSE)
###################################################
## tv.compRefl('taxref1', 'taxref2')


###################################################
### code chunk number 34: elbaue
###################################################
elbaue <- tv.veg('elbaue')
elbaue.env <- tv.site('elbaue')


###################################################
### code chunk number 35: cluster
###################################################
clust <- vector('integer', nrow(elbaue.env))
clust[elbaue.env$MGL < -50 & elbaue.env$SDGL < 50] <- 1		# dry sites, low deviation
clust[elbaue.env$MGL < -50 & elbaue.env$SDGL >= 50] <- 2	# dry sites, high deviation
clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL >= 50] <- 3	# wet sites, high deviation
clust[elbaue.env$MGL >= -50 & elbaue.env$SDGL < 50] <- 4	# wet sites, low deviation
levels(clust) <- c('dry.ld','dry.hd', 'wet.hd','wet.ld')


###################################################
### code chunk number 36: syntab.mupa
###################################################
syntab(elbaue, clust, mupa=TRUE, fullnames=TRUE)


###################################################
### code chunk number 37: vegdata.Rnw:454-462 (eval = FALSE)
###################################################
## library(rgdal)
## library(googleVis)
## coord <- data.frame(lat=T302.site$LATITUDE, long=T302.site$LONGITUDE)
## coordinates(coord) <- c("long", "lat")
## proj4string(coord) <- CRSargs(CRS("+init=epsg:31468")) # GK, 4. Stripe
## coord <- spTransform(coord, CRS("+init=epsg:4326")) # WGS 84, geographical coordinates, decimal degrees
## T302.site$long <- coordinates(coord)[,1]
## T302.site$lat <- coordinates(coord)[,2]


###################################################
### code chunk number 38: vegdata.Rnw:466-468 (eval = FALSE)
###################################################
## T302.site$loc <- paste(T302.site$LATITUDE, T302.site$LONGITUDE, sep=':')
## T302.site$tip <- paste(paste('Releve_NR:', T302.site$plotCode), paste('Table:', T302.site$referenceTable), paste('Nr. in table:', T302.site$referencePlot), paste('Date:', T302.site$obsEndDate), paste('Landuse:', T302.site$NUTZUNG), paste('Author:', T302.site$ERHEBER), paste('Locality:', T302.site$LOKALIT__T), paste('Longitude:', T302.site$LONGITUDE), paste('Latitude:', T302.site$LATITUDE), paste('geogr. Uncertaintity:', T302.site$GENAUIGKEI), sep='<BR>')


###################################################
### code chunk number 39: vegdata.Rnw:472-474 (eval = FALSE)
###################################################
## places <- gvisMap(T302.site[,c('loc','tip')], 'loc', 'tip', options=list(showTip=TRUE, showLine=FALSE, enableScrollWheel=TRUE, mapType='hybrid', useMapTypeControl=TRUE, width=1000, height=800))
## plot(places)


###################################################
### code chunk number 40: nmds
###################################################
## Data analyses
library(vegan)
veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE, noshare = 1, expand = TRUE, trace = 2)
mT.F <- meanTraits('OEK_F', elbaue)
mT.N <- meanTraits('OEK_N', elbaue)
env <- envfit(veg.nmds, data.frame(mT.F,mT.N))


###################################################
### code chunk number 41: nmdsplotfun
###################################################
library(labdsv)
library(akima)
color = function(x)rev(topo.colors(x))
nmds.plot <- function(ordi, site, var1, var2, disp, plottitle =  'NMDS', env = NULL, ...) {
 lplot <- nrow(ordi$points);  lspc <- nrow(ordi$species)
 filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1]), 
                ylim = c(-1, 1.1), xlim = c(-1.4, 1.4),
   color.palette = color, xlab = var1, ylab = var2, main = plottitle,
    key.title = title(main = var1, cex.main = 0.8, line = 1, xpd = NA),
    plot.axes = { axis(1);  axis(2)
      points(ordi$points[, 1], ordi$points[, 2], xlab = "", ylab = "", cex= .5, col = 2, pch = '+')
      points(ordi$species[, 1], ordi$species[, 2], xlab = "", ylab = "", cex=.2, pch = 19)
      ordisurf(ordi, site[, var2], col = 'black', choices = c(1, 2), add = TRUE)
      orditorp(ordi, display = disp, pch = " ")
      legend("topright", paste("GAM of ", var2), col = 'black', lty = 1)
      if(!is.null(env)) plot(env, col='red')
   }
  ,...)
}


###################################################
### code chunk number 42: nmdsplot
###################################################
print(nmds.plot(veg.nmds, elbaue.env, disp='species', 
                var1="MGL", var2="SDGL", env=env, 
                plottitle = 'NMDS of Elbaue floodplain vegetation'))


